@@ -1,6 +1,7 @@
 # external imports
 from chainlib.interface import ChainInterface
 from chainlib.eth.block import (
+        block_latest,
         block_by_number,
         Block,
         )
@@ -12,6 +13,7 @@ from chainlib.eth.tx import (
 class EthChainInterface(ChainInterface):
 
     def __init__(self):
+        self._block_latest = block_latest
         self._block_by_number = block_by_number
         self._block_from_src = Block.from_src
         self._tx_receipt = receipt
